package com.app.ui.adapter

import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Color
import android.graphics.drawable.AnimationDrawable
import android.support.v4.app.FragmentManager
import android.view.View
import android.view.ViewGroup
import android.widget.BaseAdapter
import android.widget.ImageView
import android.widget.TextView
import com.app.R
import com.app.YYApplication
import com.app.api.InterfaceUrlConstants
import com.app.api.RequestApiData
import com.app.business.YYDataPool
import com.app.constants.KeyConstants
import com.app.model.UserBase
import com.app.model.VideoGirlUser
import com.app.model.request.SponsorVideoRequest
import com.app.model.response.SponsorVideoResponse
import com.app.ui.activity.HomeActivity
import com.app.util.Tools
import com.app.util.cache.YYPreferences
import com.app.widget.dialog.DownloadVideoPluginDialog
import com.app.widget.dialog.SceneSelectionDialog
import com.sp.util.YYPreferenceSP
import com.yy.util.image.VolleyUtil
import com.yy.util.net.NewHttpResponeCallBack
import com.yy.util.string.StringUtils

/**
 * Created by liujiawei on 2017/8/1.
 */
class PopularAdapter(var activity: HomeActivity, var fragmentManager: FragmentManager) : BaseAdapter() {

    private var mData: ArrayList<VideoGirlUser>? = arrayListOf()
    private var yyDataPool: YYDataPool? = null
    private var defaultBitmap: Bitmap? = null

    init {
        yyDataPool = YYDataPool.getInstance(YYApplication.getInstance())
        defaultBitmap = BitmapFactory.decodeResource(YYApplication.getInstance().getResources(), R.drawable.woman_user_icon_default)
    }


    override fun getView(position: Int, convertView: View?, parent: ViewGroup?): View {

        var viewHolder: PopularViewHolder? = null
        var view = convertView

        if (view == null) {
            viewHolder = PopularViewHolder()
            view = View.inflate(YYApplication.getInstance(), R.layout.adapter_popular_item, null)

            viewHolder.headphoto = view.findViewById(R.id.iv_nearby_person_item_headphoto) as ImageView?
            viewHolder.nickname = view.findViewById(R.id.tv_nearby_person_item_nickname) as TextView?
            viewHolder.distance = view.findViewById(R.id.tv_nearby_person_item_distance) as TextView?
            viewHolder.age = view.findViewById(R.id.tv_nearby_person_item_age) as TextView?

            viewHolder.height = view.findViewById(R.id.tv_nearby_person_item_height) as TextView?

            viewHolder.hobby = view.findViewById(R.id.tv_nearby_person_item_hobby) as TextView?
            viewHolder.chracter = view.findViewById(R.id.tv_nearby_person_item_chracter) as TextView?
            viewHolder.chatState = view.findViewById(R.id.tv_nearby_person_item_chat_state) as TextView?

//            viewHolder.tall = view.findViewById(R.id.id_adapter_popular_tall) as ImageView?
            view.tag = viewHolder

        } else {
            viewHolder = view.tag as PopularViewHolder?
        }


        val videoGirlUser = mData?.get(position)


        val userBase = videoGirlUser?.userBase

        view?.setTag(R.id.user_tag, userBase)

        val imageUrl = userBase?.image?.imageUrl
        if (!StringUtils.isEmpty(imageUrl)) {
            YYApplication.getInstance().imageLoader.get(imageUrl,
                    VolleyUtil.getImageListener(viewHolder?.headphoto, defaultBitmap, defaultBitmap),
                    viewHolder?.headphoto!!.measuredWidth, viewHolder.headphoto!!.measuredHeight, false, 10f)
        }

        val nickName = userBase?.nickName
        viewHolder?.nickname?.text = nickName

        viewHolder?.age?.text = userBase?.age.toString() + "岁"

        viewHolder?.height?.text = userBase?.height + "cm"


        val listLabel = videoGirlUser?.listLabel

        if (listLabel?.size == 1) {
            viewHolder?.hobby?.visibility = View.VISIBLE
            viewHolder?.chracter?.visibility = View.GONE

            viewHolder?.hobby?.text = yyDataPool?.getKvsName(yyDataPool?.character_opposite, listLabel[0])
        } else if (listLabel?.size == 2) {

            viewHolder?.chracter?.visibility = View.VISIBLE

            val label = yyDataPool?.getKvsName(yyDataPool?.character_opposite, listLabel[0])
            if (StringUtils.isEmpty(label)) {
                viewHolder?.hobby?.visibility = View.GONE
            } else {
                viewHolder?.hobby?.text = label
                viewHolder?.hobby?.visibility = View.VISIBLE
            }

            viewHolder?.chracter?.text = yyDataPool?.getKvsName(yyDataPool?.interset, listLabel[1])
        } else {
            viewHolder?.hobby?.visibility = View.GONE
            viewHolder?.chracter?.visibility = View.GONE
        }
//        viewHolder?.tall?.tag = userBase
//        viewHolder?.tall?.setOnClickListener {
//            val tag = it.tag as UserBase
//            videoInvitation(tag, if (tag.showVoice == 1) SponsorVideoRequest.SRC_RECOMMENT_VOICE_CHAT else SponsorVideoRequest.SRC_RECOMMENT_VIDEO_CHAT)
//        }
//
//        if (userBase?.videoOnLine == 1) {
//            val animDrawable = YYApplication.getInstance().resources
//                    .getDrawable(R.drawable.popular_item_btn_anim) as AnimationDrawable
//            viewHolder?.tall?.setImageDrawable(animDrawable)
//            animDrawable.start()
//        } else if (userBase?.showVoice == 1) {
//
//            viewHolder?.tall?.setImageResource(R.drawable.popular_voice_item_btn)
//        } else {
//            viewHolder?.tall?.setImageResource(R.drawable.popular_item_btn_5)
//        }
//        viewHolder?.tall?.visibility = View.GONE

        if (userBase?.showVideo == 1) {
            viewHolder?.chracter?.visibility = View.GONE
            viewHolder?.chatState?.text = "可视频"
            viewHolder?.chatState?.visibility = View.VISIBLE
            viewHolder?.chatState?.setTextColor(Color.parseColor("#e08570"))
            viewHolder?.chatState?.setCompoundDrawablesWithIntrinsicBounds(R.drawable.space_round_video_icon, 0, 0, 0)
            viewHolder?.chatState?.setBackgroundResource(R.drawable.space_round_video_shape)
        } else if (userBase?.showVoice == 1) {
            viewHolder?.chracter?.visibility = View.GONE
            viewHolder?.chatState?.text = "可语音"
            viewHolder?.chatState?.visibility = View.VISIBLE
            viewHolder?.chatState?.setTextColor(Color.parseColor("#e77ba9"))
            viewHolder?.chatState?.setCompoundDrawablesWithIntrinsicBounds(R.drawable.space_round_voice_icon, 0, 0, 0)
            viewHolder?.chatState?.setBackgroundResource(R.drawable.space_round_voice_shape)
        } else {
            viewHolder?.chatState?.visibility = View.GONE
        }

        // 0-不在线，1-在线，2-空闲中，3-通话中
        if (userBase?.videoOnLine == 2) {
            // 2-空闲中
            viewHolder?.distance?.text = "空闲中"
            viewHolder?.distance?.setTextColor(Color.parseColor("#2bcf2b"))
            viewHolder?.distance?.setCompoundDrawablesWithIntrinsicBounds(R.drawable.video_free_icon, 0, 0, 0)
            viewHolder?.distance?.setPadding(0, 0, Tools.dp2px(28f), 0)
            viewHolder?.distance?.visibility = View.VISIBLE
        } else if (userBase?.videoOnLine == 3) {
            // 3-通话中
            viewHolder?.distance?.text = "通话中..."
            viewHolder?.distance?.setTextColor(Color.parseColor("#f15634"))
            viewHolder?.distance?.setCompoundDrawablesWithIntrinsicBounds(0, 0, 0, 0)
            viewHolder?.distance?.setPadding(0, 0, Tools.dp2px(18f), 0)
            viewHolder?.distance?.visibility = View.VISIBLE
        } else if (userBase?.videoOnLine == 0) {
            // 0-不在线
            viewHolder?.distance?.text = "未在线"
            viewHolder?.distance?.setTextColor(Color.parseColor("#c3c3c3"))
            viewHolder?.distance?.setCompoundDrawablesWithIntrinsicBounds(0, 0, 0, 0)
            viewHolder?.distance?.setPadding(0, 0, Tools.dp2px(28f), 0)
            viewHolder?.distance?.visibility = View.VISIBLE
        } else {
            viewHolder?.distance?.visibility = View.GONE
        }

//        viewHolder?.distance?.visibility = if (userBase?.videoOnLine == 1) View.VISIBLE else View.GONE

        return view!!
    }

    override fun getItem(position: Int): Any {

        return if (mData != null) mData!![position] else null!!
    }

    override fun getItemId(position: Int): Long {
        return position.toLong()
    }

    override fun getCount(): Int {
        return if (mData != null) mData!!.size else 0
    }


    fun setData(listUser: ArrayList<VideoGirlUser>) {
        if (this.mData != null) {
            mData!!.addAll(listUser)
        }
    }

    fun clearData() {
        if (this.mData != null) {
            mData!!.clear()
        }
    }

    /**
     * 视频邀请
     * @param userBase
     */
    fun videoInvitation(userBase: UserBase, src: Int) {
        if (YYPreferences.getInstance().getBoolean(YYPreferences.TAG_DEFAUT_SETTING, false) || src == SponsorVideoRequest.SRC_RECOMMENT_VOICE_CHAT) {// 读取默认设置状态
            var isShowFace = false
            val configInfo = YYApplication.getInstance().configInfo
            if (configInfo != null) {
                val otherCfg = configInfo.otherCfg
                if (otherCfg != null) {
                    if (otherCfg.isLeakingFacee == 1) {
                        isShowFace = true
                    }
                }
            }
            loadVideoPlugin(isShowFace, userBase, src)
        } else if (fragmentManager != null) {
            val dialog = SceneSelectionDialog().newInstance()
            dialog.show(fragmentManager, "dialog")
            dialog.setOnFinishListener { isShowFace, isDefautItme ->
                val configInfo = YYApplication.getInstance().configInfo
                if (configInfo != null) {
                    val otherCfg = configInfo.otherCfg
                    if (otherCfg != null) {
                        otherCfg.isLeakingFacee = if (isShowFace) 1 else 0
                        configInfo.otherCfg = otherCfg
                    }
                }
                YYPreferences.getInstance().putBoolean(YYPreferences.TAG_DEFAUT_SETTING, isDefautItme)
                loadVideoPlugin(isShowFace, userBase, src)
            }
        }
    }

    /**
     * 加载视频插件
     * @param isShowFace 是否露脸
     * *
     * @param userBase
     */
    private fun loadVideoPlugin(isShowFace: Boolean, userBase: UserBase?, src: Int) {

        if (userBase == null || activity == null) {
            return
        }

//        if (Tools.isAvailable(YYApplication.getInstance(), YYApplication.getInstance().VIDEO_APP_PACKAGE_NAME)) {
            val type = if (!Tools.isAvailable(YYApplication.getInstance(), YYApplication.getInstance().VIDEO_APP_PACKAGE_NAME)) 1 else 0
            val request = SponsorVideoRequest(userBase.id, YYPreferences.getInstance().userId, if (isShowFace) 1 else 0, src, type)
            RequestApiData.getInstance().sponsorVideo(request, SponsorVideoResponse::class.java, object : NewHttpResponeCallBack {
                override fun onResponeStart(apiName: String) {
                    if (InterfaceUrlConstants.URL_SPONSORVIDEO == apiName) {
                        activity.showLoadingDialog("正在邀请...")
                    }
                }

                override fun onLoading(apiName: String, count: Long, current: Long) {

                }

                override fun onSuccess(apiName: String, `object`: Any) {
                    if (InterfaceUrlConstants.URL_SPONSORVIDEO == apiName) {
                        if (`object` is SponsorVideoResponse) {
                            val response = `object`
                            val state = response.state
                            YYPreferenceSP.getInstance().putInt(KeyConstants.KEY_VIDEO_STATE, state)
                            if (state == 0 || state ==5) {// 可以连通
                                val usableTime = response.usableTime
                                val videoId = response.videoId
                                val noPwdState = response.noPwdState
                                val continueBuyUrl = response.continueBuyUrl
                                YYPreferenceSP.getInstance().putInt(KeyConstants.KEY_VIDEO_ID, videoId)

                                val url = response.url
                                YYPreferenceSP.getInstance().putString(KeyConstants.KEY_VIDEO_STATE_URL, if (state == 5) url else "")

                                if (userBase != null) {
                                    val image = userBase.image
                                    var imgUrl = ""
                                    if (image != null) {
                                        imgUrl = image.imageUrl
                                    }
                                    YYApplication.getInstance().startVideoApp(
                                            YYPreferences.getInstance().userId,
                                            userBase.id,
                                            userBase.nickName,
                                            imgUrl,
                                            YYPreferences.getInstance().gender,
                                            usableTime,
                                            isShowFace,
                                            0, 0, noPwdState, continueBuyUrl,
                                            if (activity != null) activity.supportFragmentManager else null)

                                }
                            } else if (state == 6) {
                                val usableTime = response.usableTime
                                val noPwdState = response.noPwdState
                                val continueBuyUrl = response.continueBuyUrl
                                val videoId = response.videoId
                                YYPreferenceSP.getInstance().putInt(KeyConstants.KEY_VIDEO_ID, videoId)

                                if (userBase != null) {
                                    val image = userBase.image
                                    var imgUrl = ""
                                    if (image != null) {
                                        imgUrl = image.imageUrl
                                    }
                                    YYApplication.getInstance().startVoiceApp(
                                            YYPreferences.getInstance().userId,
                                            userBase.id,
                                            userBase.nickName,
                                            imgUrl,
                                            YYPreferences.getInstance().gender,
                                            usableTime,
                                            0,
                                            noPwdState,
                                            continueBuyUrl,
                                            if (activity != null) activity.supportFragmentManager else null
                                    )
                                }

                            } else if (state == 1) {// 跳付费页面
                                val url = response.url
                                activity.showVideoPalPayActivity(url)
                            } else if (state == 2) {// 占线
                                val msg = response.msg
                                Tools.showToast(msg, 3000)
                            } else if (state == 3) {// 占线
                                val msg = response.msg
                                Tools.showToast(msg, 3000)
                            }

                            if (state != 1) {
                                activity.dismissLoadingDialog()
                            }
                        }
                    }
                }

                override fun onFailure(apiName: String, t: Throwable?, errorNo: Int, strMsg: String?) {
                    Tools.showToast(strMsg)
                    activity.dismissLoadingDialog()
                }
            })
//        } else if (fragmentManager != null) {
//            DownloadVideoPluginDialog().newInstance(DownloadVideoPluginDialog.DIALOG_LOCATION_BOTTON,
//                    "http://ptd.youyuan.com/apk/app/app_video.apk", 6).show(fragmentManager, "dialog")
//        }
    }

    class PopularViewHolder {

        var headphoto: ImageView? = null
        var nickname: TextView? = null
        var age: TextView? = null
        var height: TextView? = null

        var distance: TextView? = null

        var hobby: TextView? = null
        var chracter: TextView? = null
        var chatState: TextView? = null

//        var tall: ImageView? = null

    }
}